BwB.HRandIndex.param: Bootstrap Estimation of Hazard Function and Index Parameters

View source: R/BwB.HRandIndex.param.R

BwB.HRandIndex.paramR Documentation

Bootstrap Estimation of Hazard Function and Index Parameters

Description

Performs bootstrap estimation of hazard rates and their standard deviation at each grid point (double boostrap) together with the corresponding index parameters for a given set of bootstrap samples. The output of the function is used as input in StudentizedBwB.Index.CIs.

Usage

BwB.HRandIndex.param(B, B1, Boot.samples, marker_name1, marker_name2, 
                            event_time_name, time_name, event_name, b, t, true.haz, 
                            v.param,  hqm.est, id, xin)

Arguments

B

Integer. Number of bootstrap samples.

B1

Integer. Number of bootstrap re-samples.

Boot.samples

A list of bootstrap datasets. Each element corresponds to one replicate.

marker_name1

Character string. Name of the first longitudinal marker.

marker_name2

Character string. Name of the second longitudinal marker.

event_time_name

Name of the event time variable in the data.

time_name

Name of the time variable for the longitudinal marker measurements.

event_name

Name of the event indicator variable.

b

Numeric. Bandwidth parameter used in hazard estimation.

t

Numeric. Evaluation point for the conditional hazard.

true.haz

Numeric vector. The true or reference hazard used in the optimisation criterion.

v.param

Numeric vector. Starting values of the indexing parameters for the optimisation of the index coefficients.

hqm.est

HQM estimator on the original sample.

id

label of id variable of dataset.

xin

original sample.

Details

For each bootstrap iteration k = 1, \dots, B, the function:

  1. Extracts the bootstrap sample data.use.

  2. Computes centred marker values at the subject and observation level.

  3. Estimates index parameters by minimising index_optim using optim.

  4. Computes the bootstrap hazard estimate via Boot.hqm.

The outputs are matrices collecting the hazard estimates and estimated index parameter vectors across bootstrap replicates.

Value

A list of matrices of dimension n.est.points × B containing the bootstrap hazard estimates, the logarithm of the hazard rate estimates and and two vectors of the estimate's standard deviations at each grid point.

See Also

Boot.hqm, index_optim, to_id

Examples

  
# See the example for  function: StudentizedBwB.Index 
 
 

HQM documentation built on Jan. 8, 2026, 9:08 a.m.