| Epan | R Documentation |
Implements the Epanechnikov kernel function
Epan(x)
x |
A vector of design points where the kernel will be evaluated. |
Implements the Epanechnikov kernel function
K(x) = \frac{3}{4}(1-x^2)*(|x|<1)),
Scalar, the value of the Epanechnikov kernel at x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.