llK_b: Local linear kernel

View source: R/llK_b.R

llK_bR Documentation

Local linear kernel

Description

Implements the local linear kernel function.

Usage

llK_b(b,x,y, K)

Arguments

x

A vector of design points where the kernel will be evaluated.

y

A vector of sample data points.

b

The bandwidth to use (a scalar).

K

The kernel function to use.

Details

Implements the local linear kernel

K_{x,b}(u)= \frac{K_b(u)-K_b(u)u^T D^{-1}c_1}{c_0 - c_1^T D^{-1} c_1},

where c_1 = (c_{11}, \dots, c_{1d})^T, D = (d_{ij})_{(d+1) \times (d+1)} with

c_0 = \sum_{i=1}^n \int_0^T K_b(x-X_i(s)) Z_i(s)ds,

c_{ij} = \sum_{i=1}^n \int_0^T K_b(x-X_i(s))\{x-X_{ij}(s)\} Z_i(s)ds,

d_{jk} = \sum_{i=1}^n \int_0^T K_b(x-X_i(s))\{x-X_{ij}(s)\}\{x-X_{ik}(s)\} Z_i(s)ds,

see also Nielsen (1998), \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/03461238.1998.10413997")}.

Value

Matrix output with entries the values of the kernel function at each point.

References

Nielsen (1998), Marker dependent kernel hazard estimation from local linear estimation, Scandinavian Actuarial Journal, pp. 113-124. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/03461238.1998.10413997")}


HQM documentation built on Jan. 8, 2026, 9:08 a.m.

Related to llK_b in HQM...