| llweights | R Documentation |
Implements the weights to be used in the local linear HQM estimator.
sn.0(xin, xout, h, kfun)
sn.1(xin, xout, h, kfun)
sn.2(xin, xout, h, kfun)
xin |
Sample values. |
xout |
Grid points where the estimator will be evaluated. |
h |
Bandwidth parameter. |
kfun |
Kernel function. |
The function implements the local linear weights in the definition of the estimator \hat{h}_x(t), see also h_xt
A vector of s_n(x) for all values x on the marker grid.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.